@@ -294,12 +294,12 @@ class Assets(object):
         Arguments:
             server {string} -- Server URI
             token {string} -- Token value to be used for accessing the API
-            AssetTAG {string} -- Asset TAG             
+            AssetTag {string} -- Asset TAG             
         
         Returns:
             [string] -- Asset details from the server, in JSON formatted
         """
-        self.uri = '/api/v1/hardware/bytag/{0}'.format(str(AssetTAG))
+        self.uri = '/api/v1/hardware/bytag/{0}'.format(str(AssetTag))
         self.server = server + self.uri
         headers = {'Authorization': 'Bearer {0}'.format(token)}
         results = requests.get(self.server, headers=headers)
@@ -479,4 +479,4 @@ class Assets(object):
         self.server = server + self.uri
         headers = {'Authorization': 'Bearer {0}'.format(token)}
         results = requests.get(self.server, headers=headers)
-        return results.content
\ No newline at end of file
+        return results.content
